IPC module for the aethermap GUI
This module provides a simplified interface for the GUI to communicate with the aethermap daemon using the common IPC client.
Structs
- GuiIpc
Client - Simplified IPC client for the GUI
Type Aliases
- IpcClient
- Type alias for the IPC client used in the GUI